==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrArrayFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface JSONSchemaPropsOrArrayFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToJSONSchemas(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public A setToJSONSchemas(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public A addToJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... items);
  public A addAllToJSONSchemas(java.util.Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> items);
  public A removeFromJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... items);
  public A removeAllFromJSONSchemas(java.util.Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> items);
  public A removeMatchingFromJSONSchemas(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildJSONSchemas instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> getJSONSchemas();
  public java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> buildJSONSchemas();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildJSONSchema(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildFirstJSONSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildLastJSONSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildMatchingJSONSchema(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
  public java.lang.Boolean hasMatchingJSONSchema(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
  public A withJSONSchemas(java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> jSONSchemas);
  public A withJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... jSONSchemas);
  public java.lang.Boolean hasJSONSchemas();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> addNewJSONSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> addNewJSONSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> setNewJSONSchemaLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editJSONSchema(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editFirstJSONSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editLastJSONSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editMatchingJSONSchema(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSchema instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps getSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildSchema();
  public A withSchema(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps schema);
  public java.lang.Boolean hasSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<A> withNewSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<A> withNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<A> editSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<A> editOrNewSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<A> editOrNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public interface JSONSchemasNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluent<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<N>>{
    public N and();
    public N endJSONSchema();
    
  }
  public interface SchemaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluent<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<N>>{
    public N and();
    public N endSchema();
    
  }
  
}

==> kubernetes-model-apiextensions-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrArrayFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface JSONSchemaPropsOrArrayFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToJSONSchemas(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public A setToJSONSchemas(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public A addToJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... items);
  public A addAllToJSONSchemas(java.util.Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> items);
  public A removeFromJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... items);
  public A removeAllFromJSONSchemas(java.util.Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> items);
  public A removeMatchingFromJSONSchemas(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildJSONSchemas instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> getJSONSchemas();
  public java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> buildJSONSchemas();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildJSONSchema(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildFirstJSONSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildLastJSONSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildMatchingJSONSchema(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
  public java.lang.Boolean hasMatchingJSONSchema(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
  public A withJSONSchemas(java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> jSONSchemas);
  public A withJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... jSONSchemas);
  public java.lang.Boolean hasJSONSchemas();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> addNewJSONSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> addNewJSONSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> setNewJSONSchemaLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editJSONSchema(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editFirstJSONSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editLastJSONSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editMatchingJSONSchema(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSchema instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps getSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildSchema();
  public A withSchema(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps schema);
  public java.lang.Boolean hasSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<A> withNewSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<A> withNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<A> editSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<A> editOrNewSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<A> editOrNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface JSONSchemasNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluent<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.JSONSchemasNested<N>>{
    public N and();
    public N endJSONSchema();
    
  }
  public interface SchemaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluent<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent.SchemaNested<N>>{
    public N and();
    public N endSchema();
    
  }
  
}
